INSERT INTO shipping_zone (id, name, status) VALUES (1, 'Europe', 0);
INSERT INTO shipping_zone (id, name, status) VALUES (2, 'US', 1);
INSERT INTO shipping_zone (id, name, status) VALUES (3, 'Asia', 1);
INSERT INTO shipping_zone (id, name, status) VALUES (4, 'Africa', 0);
INSERT INTO shipping_zone (id, name, status) VALUES (5, 'Oceania', 0);
INSERT INTO shipping_zone (id, name, status) VALUES (6, 'Brasil', 1);