#shipping-freight{

}

#shipping-freight .clearfix {
  *zoom: 1;
}
#shipping-freight.clearfix:before,
#shipping-freight.clearfix:after {
  display: table;
  content: "";
  line-height: 0;
}
#shipping-freight.clearfix:after {
  clear: both;
}

#shipping-freight label{
    display:block;
    float:left;
    width:120px;
}

#shipping-freight select{
    width:150px;
}


#shipping-freight .shipping-full-address{
    display:none;
}

.shipping-loader{
    display:none;
}

.shipping-loading .shipping-loader{
    display:block !important;
}