INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (1, "Germany", "DE", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (2, "Austria", "AT", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (3, "Belgium", "BE", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (4, "Canada", "CA", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (5, "China", "CN", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (6, "Spain", "ES", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (7, "Finland", "FI", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (8, "France", "FR", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (9, "Greece", "GR", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (10, "Italy", "IT", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (11, "Japan", "JP", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (12, "Luxemburg", "LU", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (13, "Netherlands", "NL", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (14, "Poland", "PL", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (15, "Portugal", "PT", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (16, "Czech Republic", "CZ", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (17, "United Kingdom", "GB", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (18, "Sweden", "SE", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (19, "Switzerland", "CH", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (20, "Denmark", "DK", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (21, "United State", "US", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (22, "HongKong", "HK", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (23, "Norway", "NO", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (24, "Australia", "AU", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (25, "Singapore", "SG", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (26, "Ireland", "IE", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (27, "New Zealand", "NZ", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (28, "South Korea", "KR", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (29, "Israel", "IL", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (30, "South 4", "ZA", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (31, "Nigeria", "NG", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (32, "Ivory Coast", "CI", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (33, "Togo", "TG", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (34, "Bolivia", "BO", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (35, "Mauritius", "MU", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (36, "Romania", "RO", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (37, "Slovakia", "SK", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (38, "Algeria", "DZ", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (39, "American Samoa", "AS", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (40, "Andorra", "AD", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (41, "Angola", "AO", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (42, "Anguilla", "AI", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (43, "Antigua and Barbuda", "AG", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (44, "Argentina", "AR", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (45, "Armenia", "AM", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (46, "Aruba", "AW", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (47, "Azerbaijan", "AZ", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (48, "Bahamas", "BS", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (49, "Bahrain", "BH", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (50, "Bangladesh", "BD", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (51, "Barbados", "BB", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (52, "Belarus", "BY", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (53, "Belize", "BZ", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (54, "Benin", "BJ", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (55, "Bermuda", "BM", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (56, "Bhutan", "BT", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (57, "Botswana", "BW", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (58, "Brazil", "BR", 1, 6);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (59, "Brunei", "BN", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (60, "Burkina Faso", "BF", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (61, "Burma (Myanmar)", "MM", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (62, "Burundi", "BI", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (63, "Cambodia", "KH", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (64, "Cameroon", "CM", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (65, "Cape Verde", "CV", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (66, "Central 4n Republic", "CF", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (67, "Chad", "TD", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (68, "Chile", "CL", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (69, "Colombia", "CO", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (70, "Comoros", "KM", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (71, "Congo, Dem. Republic", "CD", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (72, "Congo, Republic", "CG", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (73, "Costa Rica", "CR", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (74, "Croatia", "HR", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (75, "Cuba", "CU", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (76, "Cyprus", "CY", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (77, "Djibouti", "DJ", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (78, "Dominica", "DM", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (79, "Dominican Republic", "DO", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (80, "East Timor", "TL", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (81, "Ecuador", "EC", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (82, "Egypt", "EG", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (83, "El Salvador", "SV", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (84, "Equatorial Guinea", "GQ", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (85, "Eritrea", "ER", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (86, "Estonia", "EE", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (87, "Ethiopia", "ET", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (88, "Falkland Islands", "FK", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (89, "Faroe Islands", "FO", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (90, "Fiji", "FJ", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (91, "Gabon", "GA", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (92, "Gambia", "GM", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (93, "Georgia", "GE", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (94, "Ghana", "GH", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (95, "Grenada", "GD", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (96, "Greenland", "GL", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (97, "Gibraltar", "GI", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (98, "Guadeloupe", "GP", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (99, "Guam", "GU", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (100, "Guatemala", "GT", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (101, "Guernsey", "GG", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (102, "Guinea", "GN", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (103, "Guinea-Bissau", "GW", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (104, "Guyana", "GY", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (105, "Haiti", "HT", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (106, "Heard Island and McDonald Islands", "HM", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (107, "Vatican City State", "VA", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (108, "Honduras", "HN", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (109, "Iceland", "IS", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (110, "India", "IN", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (111, "Indonesia", "ID", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (112, "Iran", "IR", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (113, "Iraq", "IQ", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (114, "Isle of Man", "IM", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (115, "Jamaica", "JM", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (116, "Jersey", "JE", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (117, "Jordan", "JO", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (118, "Kazakhstan", "KZ", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (119, "Kenya", "KE", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (120, "Kiribati", "KI", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (121, "Korea, Dem. Republic of", "KP", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (122, "Kuwait", "KW", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (123, "Kyrgyzstan", "KG", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (124, "Laos", "LA", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (125, "Latvia", "LV", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (126, "Lebanon", "LB", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (127, "Lesotho", "LS", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (128, "Liberia", "LR", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (129, "Libya", "LY", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (130, "Liechtenstein", "LI", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (131, "Lithuania", "LT", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (132, "Macau", "MO", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (133, "Macedonia", "MK", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (134, "Madagascar", "MG", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (135, "Malawi", "MW", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (136, "Malaysia", "MY", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (137, "Maldives", "MV", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (138, "Mali", "ML", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (139, "Malta", "MT", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (140, "Marshall Islands", "MH", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (141, "Martinique", "MQ", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (142, "Mauritania", "MR", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (143, "Hungary", "HU", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (144, "Mayotte", "YT", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (145, "Mexico", "MX", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (146, "Micronesia", "FM", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (147, "Moldova", "MD", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (148, "Monaco", "MC", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (149, "Mongolia", "MN", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (150, "Montenegro", "ME", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (151, "Montserrat", "MS", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (152, "Morocco", "MA", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (153, "Mozambique", "MZ", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (154, "Namibia", "NA", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (155, "Nauru", "NR", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (156, "Nepal", "NP", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (157, "Netherlands Antilles", "AN", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (158, "New Caledonia", "NC", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (159, "Nicaragua", "NI", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (160, "Niger", "NE", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (161, "Niue", "NU", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (162, "Norfolk Island", "NF", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (163, "Northern Mariana Islands", "MP", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (164, "Oman", "OM", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (165, "Pakistan", "PK", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (166, "Palau", "PW", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (167, "Palestinian Territories", "PS", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (168, "Panama", "PA", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (169, "Papua New Guinea", "PG", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (170, "Paraguay", "PY", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (171, "Peru", "PE", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (172, "Philippines", "PH", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (173, "Pitcairn", "PN", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (174, "Puerto Rico", "PR", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (175, "Qatar", "QA", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (176, "Réunion", "RE", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (177, "Russian Federation", "RU", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (178, "Rwanda", "RW", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (179, "Saint Barthélemy", "BL", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (180, "Saint Kitts and Nevis", "KN", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (181, "Saint Lucia", "LC", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (182, "Saint Martin", "MF", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (183, "Saint Pierre and Miquelon", "PM", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (184, "Saint Vincent and the Grenadines", "VC", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (185, "Samoa", "WS", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (186, "San Marino", "SM", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (187, "São Tomé and Príncipe", "ST", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (188, "Saudi Arabia", "SA", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (189, "Senegal", "SN", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (190, "Serbia", "RS", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (191, "Seychelles", "SC", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (192, "Sierra Leone", "SL", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (193, "Slovenia", "SI", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (194, "Solomon Islands", "SB", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (195, "Somalia", "SO", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (196, "South Georgia and the South Sandwich Islands", "GS", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (197, "Sri Lanka", "LK", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (198, "Sudan", "SD", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (199, "Suriname", "SR", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (200, "Svalbard and Jan Mayen", "SJ", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (201, "Swaziland", "SZ", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (202, "Syria", "SY", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (203, "Taiwan", "TW", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (204, "Tajikistan", "TJ", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (205, "Tanzania", "TZ", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (206, "Thailand", "TH", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (207, "Tokelau", "TK", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (208, "Tonga", "TO", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (209, "Trinidad and Tobago", "TT", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (210, "Tunisia", "TN", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (211, "Turkey", "TR", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (212, "Turkmenistan", "TM", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (213, "Turks and Caicos Islands", "TC", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (214, "Tuvalu", "TV", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (215, "Uganda", "UG", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (216, "Ukraine", "UA", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (217, "United Arab Emirates", "AE", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (218, "Uruguay", "UY", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (219, "Uzbekistan", "UZ", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (220, "Vanuatu", "VU", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (221, "Venezuela", "VE", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (222, "Vietnam", "VN", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (223, "Virgin Islands (British)", "VG", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (224, "Virgin Islands (U.S.)", "VI", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (225, "Wallis and Futuna", "WF", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (226, "Western Sahara", "EH", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (227, "Yemen", "YE", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (228, "Zambia", "ZM", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (229, "Zimbabwe", "ZW", 1, 4);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (230, "Albania", "AL", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (231, "Afghanistan", "AF", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (232, "Antarctica", "AQ", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (233, "Bosnia and Herzegovina", "BA", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (234, "Bouvet Island", "BV", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (235, "British Indian Ocean Territory", "IO", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (236, "Bulgaria", "BG", 1, 1);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (237, "Cayman Islands", "KY", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (238, "Christmas Island", "CX", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (239, "Cocos (Keeling) Islands", "CC", 1, 3);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (240, "Cook Islands", "CK", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (241, "French Guiana", "GF", 1, 2);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (242, "French Polynesia", "PF", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (243, "French Southern Territories", "TF", 1, 5);
INSERT INTO shipping_country (id, name, iso, status, zone_id) VALUES (244, "Åland Islands", "AX", 1, 1);