INSERT INTO shipping_state (id, name, iso, country_id) VALUES (1, "Alabama", "AL", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (2, "Alaska", "AK", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (3, "Arizona", "AZ", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (4, "Arkansas", "AR", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (5, "California", "CA", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (6, "Colorado", "CO", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (7, "Connecticut", "CT", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (8, "Delaware", "DE", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (9, "Florida", "FL", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (10, "Georgia", "GA", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (11, "Hawaii", "HI", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (12, "Idaho", "ID", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (13, "Illinois", "IL", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (14, "Indiana", "IN", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (15, "Iowa", "IA", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (16, "Kansas", "KS", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (17, "Kentucky", "KY", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (18, "Louisiana", "LA", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (19, "Maine", "ME", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (20, "Maryland", "MD", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (21, "Massachusetts", "MA", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (22, "Michigan", "MI", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (23, "Minnesota", "MN", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (24, "Mississippi", "MS", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (25, "Missouri", "MO", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (26, "Montana", "MT", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (27, "Nebraska", "NE", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (28, "Nevada", "NV", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (29, "New Hampshire", "NH", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (30, "New Jersey", "NJ", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (31, "New Mexico", "NM", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (32, "New York", "NY", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (33, "North Carolina", "NC", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (34, "North Dakota", "ND", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (35, "Ohio", "OH", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (36, "Oklahoma", "OK", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (37, "Oregon", "OR", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (38, "Pennsylvania", "PA", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (39, "Rhode Island", "RI", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (40, "South Carolina", "SC", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (41, "South Dakota", "SD", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (42, "Tennessee", "TN", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (43, "Texas", "TX", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (44, "Utah", "UT", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (45, "Vermont", "VT", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (46, "Virginia", "VA", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (47, "Washington", "WA", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (48, "West Virginia", "WV", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (49, "Wisconsin", "WI", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (50, "Wyoming", "WY", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (51, "Puerto Rico", "PR", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (52, "2 Virgin Islands", "VI", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (53, "District of Columbia", "DC", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (54, "Aguascalientes", "AGS", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (55, "Baja California", "BCN", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (56, "Baja California Sur", "BCS", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (57, "Campeche", "CAM", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (58, "Chiapas", "CHP", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (59, "Chihuahua", "CHH", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (60, "Coahuila", "COA", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (61, "Colima", "COL", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (62, "Distrito Federal", "DIF", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (63, "Durango", "DUR", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (64, "Guanajuato", "GUA", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (65, "Guerrero", "GRO", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (66, "Hidalgo", "HID", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (67, "Jalisco", "JAL", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (68, "Estado de México", "MEX", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (69, "Michoacán", "MIC", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (70, "Morelos", "MOR", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (71, "Nayarit", "NAY", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (72, "Nuevo León", "NLE", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (73, "Oaxaca", "OAX", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (74, "Puebla", "PUE", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (75, "Querétaro", "QUE", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (76, "Quintana Roo", "ROO", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (77, "San Luis Potosí", "SLP", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (78, "Sinaloa", "SIN", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (79, "Sonora", "SON", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (80, "Tabasco", "TAB", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (81, "Tamaulipas", "TAM", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (82, "Tlaxcala", "TLA", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (83, "Veracruz", "VER", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (84, "Yucatán", "YUC", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (85, "Zacatecas", "ZAC", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (86, "Ontario", "ON", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (87, "Quebec", "QC", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (88, "British Columbia", "BC", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (89, "Alberta", "AB", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (90, "Manitoba", "MB", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (91, "Saskatchewan", "SK", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (92, "Nova Scotia", "NS", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (93, "New Brunswick", "NB", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (94, "Newfoundland and Labrador", "NL", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (95, "Prince Edward Island", "PE", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (96, "Northwest Territories", "NT", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (97, "Yukon", "YT", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (98, "Nunavut", "NU", 21);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (99, "Acre", "AC", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (100, "Alagoas", "AL", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (101, "Amapá", "AP", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (102, "Amazonas", "AM", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (103, "Bahia", "BA", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (104, "Ceará", "CE", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (105, "Distrito Federal", "DF", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (106, "Espírito Santo", "ES", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (107, "Goiás", "GO", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (108, "Maranhão", "MA", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (109, "Mato Grosso", "MT", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (110, "Mato Grosso do Sul", "MS", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (111, "Minas Gerais", "MG", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (112, "Pará", "PA", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (113, "Paraíba", "PB", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (114, "Paraná", "PR", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (115, "Pernambuco", "PE", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (116, "Piauí", "PI", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (117, "Rio de Janeiro", "RJ", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (118, "Rio Grande do Norte", "RN", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (119, "Rio Grande do Sul", "RS", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (120, "Rondônia", "RO", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (121, "Roraima", "RR", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (122, "Santa Catarina", "SC", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (123, "São Paulo", "SP", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (124, "Sergipe", "SE", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (125, "Tocantins", "TO", 58);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (126, "Beijing", "11", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (127, "Chongqing", "50", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (128, "Shanghaï", "31", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (129, "Tianjin", "12", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (130, "Anhui", "34", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (131, "Fujian", "35", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (132, "Gansu", "62", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (133, "Guangdong", "44", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (134, "Guizhou", "52", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (135, "Hainan", "46", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (136, "Hebei", "13", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (137, "Heilongjiang", "23", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (138, "Henan", "41", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (139, "Hubei", "42", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (140, "Hunan", "43", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (141, "Jiangsu", "32", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (142, "Jiangxi", "36", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (143, "Jilin", "22", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (144, "Liaoning", "21", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (145, "Qinghai", "63", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (146, "Shaanxi", "61", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (147, "Shandong", "37", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (148, "Shanxi", "14", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (149, "Sichuan", "51", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (150, "Taïwan", "71", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (151, "Yunnan", "53", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (152, "Guangxi", "45", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (153, "Neimenggu", "15", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (154, "Ningxia", "64", 5);
INSERT INTO shipping_state (id, name, iso, country_id) VALUES (155, "Xinjiang", "65", 5);